@@ -5,7 +5,7 @@ Package et_ppmdcommon
 
 Common components for the Parallel Programming project assignment
 """
-__version__ = "0.3.3"
+__version__ = "0.3.4"
 
 import numpy as np
 import math
@@ -141,17 +141,17 @@ def figure():
     return fig, ax
 
 
-def plotAtoms(x,y,r=0.0):
+def plotAtoms(x,y,radius=0.0):
     """Plot the atoms on current matplotlib figure 
 
     :param np.array x: x-coordinates
     :param np.array y: y-coordinates
-    :param float r: atom radius, if 0.0 dots are plotted
+    :param float radius: atom radius, if 0.0 dots are plotted
     """
-    if r:
+    if radius:
         theta = np.linspace(0,2*np.pi,36,endpoint=True)
-        xCircle = r*np.cos(theta)
-        yCircle = r*np.sin(theta)
+        xCircle = radius*np.cos(theta)
+        yCircle = radius*np.sin(theta)
         for i in range(len(x)):
             xCircle += x[i]
             yCircle += y[i]
